@@ -35,7 +35,8 @@ read_ima <- function(fraw, verbose = FALSE, extra) {
                RepetitionTime = vars$tr,
                FlipAngle = vars$flip_ang,
                SequenceName = vars$seq_fname,
-               ChemicalShiftReference = 4.7 + vars$delta_freq)
+               ChemicalShiftReference = 4.7 + vars$delta_freq,
+               Manufacturer = "Siemens")
   
   mrs_data <- mrs_data(data = data, ft = vars$ft, resolution = paras$res,
                        ref = paras$ref, nuc = paras$nuc,
