@@ -54,20 +54,50 @@ read_pfile <- function(fname, n_ref_scans = NULL, verbose, extra) {
     cat(paste("nechoes     :", hdr$nechoes), "\n")
     cat(paste("frame_size  :", hdr$frame_size), "\n")
     cat(paste("w_frames    :", hdr$rhuser19), "\n")
-    cat(paste("Header rev. :", hdr$hdr_rev), "\n\n")
+    cat(paste("Header rev. :", hdr$hdr_rev), "\n")
+    cat(paste("Seq. name   :", hdr$seq_name), "\n")
+    cat(paste("CSI dims    :", hdr$csi_dims), "\n")
+    cat(paste("xcsi        :", hdr$xcsi), "\n")
+    cat(paste("ycsi        :", hdr$ycsi), "\n")
+    cat(paste("zcsi        :", hdr$zcsi), "\n\n")
   }
   
   data <- raw_pts[c(TRUE, FALSE)] + 1i * raw_pts[c(FALSE, TRUE)]
   
-  dyns <- hdr$nechoes * hdr$nframes + hdr$nechoes
-  
-  data <- array(data, dim = c(hdr$frame_size, dyns, coils, 1, 1, 1, 1))
-  
-  data <- aperm(data, c(7,6,5,4,2,3,1))
-  
-  # remove the empty frame at the start of each coil for each echo
-  rem <- seq(from = 1, to = dyns, by = dyns / hdr$nechoes)
-  data <- data[,,,,-rem,,,drop = FALSE]
+  if (hdr$csi_dims == 0) {
+    # looks like SVS
+    dyns <- hdr$nechoes * hdr$nframes + hdr$nechoes
+    data <- array(data, dim = c(hdr$frame_size, dyns, coils, 1, 1, 1, 1))
+    data <- aperm(data, c(7, 6, 5, 4, 2, 3, 1))
+    
+    # remove the empty frame at the start of each coil for each echo
+    rem <- seq(from = 1, to = dyns, by = dyns / hdr$nechoes)
+    data <- data[,,,,-rem,,,drop = FALSE]
+  } else {
+    # looks like MRSI
+    
+    # the + 1 is an empty FID at the start of each coil 
+    data <- array(data, dim = c(hdr$frame_size, hdr$xcsi * hdr$ycsi + 1, coils,
+                                1, 1, 1, 1))
+    
+    data <- aperm(data, c(7, 6, 5, 4, 2, 3, 1))
+    
+    # remove the empty FID
+    data <- data[,,,,-1,,,drop = FALSE]
+    
+    # reshape
+    new_dim <- dim(data)
+    new_dim[2] <- hdr$xcsi
+    new_dim[3] <- hdr$ycsi
+    new_dim[5] <- 1
+    
+    dim(data) <- new_dim
+    
+    # phase cycling correction?
+    k_sp_corr_x <- array(1, dim(data))
+    k_sp_corr_x[, c(T, F),,,,,] <- -1
+    data <- data * k_sp_corr_x
+}
   
   res <- c(NA, NA, NA, NA, 1, NA, 1 / hdr$spec_width)
   
@@ -78,6 +108,8 @@ read_pfile <- function(fname, n_ref_scans = NULL, verbose, extra) {
   nuc <- def_nuc()
   
   meta <- list(EchoTime = hdr$te,
+               RepetitionTime = hdr$tr,
+               SequenceName = hdr$seq_name,
                Manufacturer = "GE")
   
   mrs_data <- mrs_data(data = data, ft = hdr$ps_mps_freq / 10, resolution = res,
@@ -92,9 +124,18 @@ read_pfile <- function(fname, n_ref_scans = NULL, verbose, extra) {
     
     ref_mrs <- get_dyns(mrs_data, which(wref_inds))
     metab_mrs <- get_dyns(mrs_data, which(!wref_inds))
+    
+    if (hdr$csi_dims > 0) {
+      ref_mrs   <- img2kspace_xy(ref_mrs)
+      metab_mrs <- img2kspace_xy(metab_mrs)
+    }
   } else {
     ref_mrs <- NA
     metab_mrs <- mrs_data
+    
+    if (hdr$csi_dims > 0) {
+      metab_mrs <- img2kspace_xy(metab_mrs)
+    }
   }
   
   out <- list(metab = metab_mrs, ref = ref_mrs)
@@ -153,19 +194,29 @@ read_pfile_header <- function(fname) {
   seek(con, loc$te)
   vars$te <- readBin(con, "int", size = 4, endian = endian) / 1e6
   
+  seek(con, loc$tr)
+  vars$tr <- readBin(con, "int", size = 4, endian = endian) / 1e6
+  
+  seek(con, loc$seq_name)
+  vars$seq_name <- readBin(con, "character", size = 33)
+  
   close(con)
   
   vars
 }
 
 get_pfile_vars <- function() {
-  vars <- vector(mode = "list", length = 14)
+  vars <- vector(mode = "list", length = 16)
   names(vars) <- c("hdr_rev", "off_data", "nechoes", "nframes", "frame_size", 
                    "rcv", "rhuser19", "spec_width", "csi_dims", "xcsi", "ycsi",
-                   "zcsi", "ps_mps_freq", "te")
+                   "zcsi", "ps_mps_freq", "te", "tr", "seq_name")
   vars
 }
 
+# following are useful resources for GE p-files
+# https://github.com/SIVICLab/sivic/blob/master/libs/src/svkGEPFileReader.cc
+# https://github.com/chenkonturek/MRS_MRI_libs/blob/master/MRS_lib/io/mrs_readGEpfile.m
+
 get_pfile_dict <- function(hdr_rev, con) {
   loc <- get_pfile_vars()
   
@@ -184,6 +235,8 @@ get_pfile_dict <- function(hdr_rev, con) {
     loc$zcsi        <- 442
     loc$ps_mps_freq <- 488
     loc$te          <- 1148
+    loc$tr          <- 199236
+    loc$seq_name    <- 199812
   } else if ((floor(hdr_rev) > 11) && (floor(hdr_rev) < 25)) {
     loc$hdr_rev     <- 0
     loc$off_data    <- 1468
@@ -199,6 +252,8 @@ get_pfile_dict <- function(hdr_rev, con) {
     loc$zcsi        <- 378
     loc$ps_mps_freq <- 424
     loc$te          <- 1212
+    loc$tr          <- 148944
+    loc$seq_name    <- 149520
   } else {
     close(con)
     stop(paste("Error, pfile version not supported :", hdr_rev))
